Enum consensus::network_interface::ConsensusMsg [−][src]
pub enum ConsensusMsg {
BlockRetrievalRequest(Box<BlockRetrievalRequest>),
BlockRetrievalResponse(Box<BlockRetrievalResponse>),
EpochRetrievalRequest(Box<EpochRetrievalRequest>),
ProposalMsg(Box<ProposalMsg>),
SyncInfo(Box<SyncInfo>),
EpochChangeProof(Box<EpochChangeProof>),
VoteMsg(Box<VoteMsg>),
CommitVoteMsg(Box<CommitVote>),
CommitDecisionMsg(Box<CommitDecision>),
}Expand description
Network type for consensus
Variants
BlockRetrievalRequest(Box<BlockRetrievalRequest>)RPC to get a chain of block of the given length starting from the given block id.
Tuple Fields of BlockRetrievalRequest
BlockRetrievalResponse(Box<BlockRetrievalResponse>)Carries the returned blocks and the retrieval status.
Tuple Fields of BlockRetrievalResponse
EpochRetrievalRequest(Box<EpochRetrievalRequest>)Request to get a EpochChangeProof from current_epoch to target_epoch
Tuple Fields of EpochRetrievalRequest
ProposalMsg(Box<ProposalMsg>)ProposalMsg contains the required information for the proposer election protocol to make its choice (typically depends on round and proposer info).
Tuple Fields of ProposalMsg
0: Box<ProposalMsg>This struct describes basic synchronization metadata.
EpochChangeProof(Box<EpochChangeProof>)A vector of LedgerInfo with contiguous increasing epoch numbers to prove a sequence of epoch changes from the first LedgerInfo’s epoch.
Tuple Fields of EpochChangeProof
0: Box<EpochChangeProof>VoteMsg is the struct that is ultimately sent by the voter in response for receiving a proposal.
CommitVoteMsg(Box<CommitVote>)CommitProposal is the struct that is sent by the validator after execution to propose on the committed state hash root.
Tuple Fields of CommitVoteMsg
0: Box<CommitVote>CommitDecisionMsg(Box<CommitDecision>)CommitDecision is the struct that is sent by the validator after collecting no fewer than 2f + 1 signatures on the commit proposal. This part is not on the critical path, but it can save slow machines to quickly confirm the execution result.
Tuple Fields of CommitDecisionMsg
0: Box<CommitDecision>Trait Implementations
Send a single message to the destination peer using available ProtocolId.
fn send_to_many(
&self,
recipients: impl Iterator<Item = PeerId>,
message: ConsensusMsg
) -> Result<(), NetworkError>
fn send_to_many(
&self,
recipients: impl Iterator<Item = PeerId>,
message: ConsensusMsg
) -> Result<(), NetworkError>
Send a single message to the destination peers using available ProtocolId.
Send a RPC to the destination peer using the CONSENSUS_RPC_PROTOCOL ProtocolId.
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more