Struct consensus::network_interface::ConsensusNetworkSender [−][src]
pub struct ConsensusNetworkSender { /* fields omitted */ }Expand description
The interface from Consensus to Networking layer.
This is a thin wrapper around a NetworkSender<ConsensusMsg>, so it is easy
to clone and send off to a separate task. For example, the rpc requests
return Futures that encapsulate the whole flow, from sending the request to
remote, to finally receiving the response and deserializing. It therefore
makes the most sense to make the rpc call on a separate async task, which
requires the ConsensusNetworkSender to be Clone and Send.
Implementations
Initialize a shared hashmap about connections metadata that is updated by the receiver.